==> apache-camel-3.2.0-src.zip: apache-camel-3.2.0/core/camel-cloud/src/main/java/org/apache/camel/impl/cloud/DefaultServiceDiscovery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.cloud;

import java.util.Collections;
import java.util.List;

import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.cloud.ServiceDefinition;
import org.apache.camel.cloud.ServiceDiscovery;
import org.apache.camel.support.service.ServiceSupport;

public class DefaultServiceDiscovery
    extends ServiceSupport implements ServiceDiscovery, CamelContextAware {

    private CamelContext camelContext;

    @Override
    public List<ServiceDefinition> getServices(String name) {
        return Collections.emptyList();
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    protected void doStart() throws Exception {
        // nop
    }

    @Override
    protected void doStop() throws Exception {
        // nop
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/core/camel-cloud/src/main/java/org/apache/camel/impl/cloud/DefaultServiceDiscovery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.impl.cloud;

import java.util.Collections;
import java.util.List;

import org.apache.camel.CamelContext;
import org.apache.camel.CamelContextAware;
import org.apache.camel.cloud.ServiceDefinition;
import org.apache.camel.cloud.ServiceDiscovery;
import org.apache.camel.support.service.ServiceSupport;

/**
 * @deprecated since 4.7
 */
@Deprecated(since = "4.7")
public class DefaultServiceDiscovery
        extends ServiceSupport
        implements ServiceDiscovery, CamelContextAware {

    private CamelContext camelContext;

    @Override
    public List<ServiceDefinition> getServices(String name) {
        return Collections.emptyList();
    }

    @Override
    public void setCamelContext(CamelContext camelContext) {
        this.camelContext = camelContext;
    }

    @Override
    public CamelContext getCamelContext() {
        return camelContext;
    }

    @Override
    protected void doStart() throws Exception {
        // nop
    }

    @Override
    protected void doStop() throws Exception {
        // nop
    }
}
